@@ -1159,7 +1159,8 @@ ch_device_get_serial_number (GUsbDevice *device, guint32 *value,
 			g_set_error (error,
 				     G_USB_DEVICE_ERROR,
 				     G_USB_DEVICE_ERROR_IO,
-				     "Invalid size, got %li", actual_length);
+				     "Invalid size, got %" G_GSIZE_FORMAT,
+				     actual_length);
 			return FALSE;
 		}
 		if (value != NULL)
@@ -1282,7 +1283,8 @@ ch_device_get_leds (GUsbDevice *device, ChStatusLed *value,
 			g_set_error (error,
 				     G_USB_DEVICE_ERROR,
 				     G_USB_DEVICE_ERROR_IO,
-				     "Invalid size, got %li", actual_length);
+				     "Invalid size, got %" G_GSIZE_FORMAT,
+				     actual_length);
 			return FALSE;
 		}
 		if (value != NULL)
@@ -1296,6 +1298,106 @@ ch_device_get_leds (GUsbDevice *device, ChStatusLed *value,
 	return FALSE;
 }
 
+/**
+ * ch_device_set_illuminants:
+ * @device: A #GUsbDevice
+ * @value: serial number
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Sets the illuminants on the device
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+gboolean
+ch_device_set_illuminants (GUsbDevice *device, ChIlluminant value,
+			   GCancellable *cancellable, GError **error)
+{
+	if (ch_device_get_protocol_ver (device) != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "Setting the illuminants is not supported");
+		return FALSE;
+	}
+	return g_usb_device_control_transfer (device,
+					      G_USB_DEVICE_DIRECTION_HOST_TO_DEVICE,
+					      G_USB_DEVICE_REQUEST_TYPE_CLASS,
+					      G_USB_DEVICE_RECIPIENT_INTERFACE,
+					      CH_CMD_SET_ILLUMINANTS,
+					      value,		/* wValue */
+					      CH_USB_INTERFACE,	/* idx */
+					      NULL,		/* data */
+					      0,		/* length */
+					      NULL,		/* actual_length */
+					      CH_DEVICE_USB_TIMEOUT,
+					      cancellable,
+					      error);
+}
+
+/**
+ * ch_device_get_illuminants:
+ * @device: A #GUsbDevice
+ * @value: (out): serial number
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Gets the illuminants from the device.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+gboolean
+ch_device_get_illuminants (GUsbDevice *device, ChIlluminant *value,
+			   GCancellable *cancellable, GError **error)
+{
+	guint8 buf[1];
+	gsize actual_length;
+	gboolean ret;
+
+	g_return_val_if_fail (G_USB_DEVICE (device), FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	if (ch_device_get_protocol_ver (device) != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "Getting the illuminants is not supported");
+		return FALSE;
+	}
+	ret = g_usb_device_control_transfer (device,
+					     G_USB_DEVICE_DIRECTION_DEVICE_TO_HOST,
+					     G_USB_DEVICE_REQUEST_TYPE_CLASS,
+					     G_USB_DEVICE_RECIPIENT_INTERFACE,
+					     CH_CMD_GET_ILLUMINANTS,
+					     0x00,		/* wValue */
+					     CH_USB_INTERFACE,	/* idx */
+					     buf,		/* data */
+					     sizeof(buf),	/* length */
+					     &actual_length,
+					     CH_DEVICE_USB_TIMEOUT,
+					     cancellable,
+					     error);
+	if (!ret)
+		return FALSE;
+
+	/* return result */
+	if (actual_length != sizeof(buf)) {
+		g_set_error (error,
+			     G_USB_DEVICE_ERROR,
+			     G_USB_DEVICE_ERROR_IO,
+			     "Invalid size, got %" G_GSIZE_FORMAT,
+			     actual_length);
+		return FALSE;
+	}
+	if (value != NULL)
+		memcpy (value, buf, sizeof(buf));
+	return TRUE;
+}
+
 /**
  * ch_device_set_pcb_errata:
  * @device: A #GUsbDevice
@@ -1418,7 +1520,8 @@ ch_device_get_pcb_errata (GUsbDevice *device, ChPcbErrata *value,
 			g_set_error (error,
 				     G_USB_DEVICE_ERROR,
 				     G_USB_DEVICE_ERROR_IO,
-				     "Invalid size, got %li", actual_length);
+				     "Invalid size, got %" G_GSIZE_FORMAT,
+				     actual_length);
 			return FALSE;
 		}
 		if (value != NULL)
@@ -1610,7 +1713,8 @@ ch_device_get_ccd_calibration (GUsbDevice *device,
 		g_set_error (error,
 			     G_USB_DEVICE_ERROR,
 			     G_USB_DEVICE_ERROR_IO,
-			     "Invalid size, got %li", actual_length);
+			     "Invalid size, got %" G_GSIZE_FORMAT,
+				     actual_length);
 		return FALSE;
 	}
 	if (start_nm != NULL) {
@@ -1737,7 +1841,8 @@ ch_device_get_integral_time (GUsbDevice *device, guint16 *value,
 			g_set_error (error,
 				     G_USB_DEVICE_ERROR,
 				     G_USB_DEVICE_ERROR_IO,
-				     "Invalid size, got %li", actual_length);
+				     "Invalid size, got %" G_GSIZE_FORMAT,
+				     actual_length);
 			return FALSE;
 		}
 		if (value != NULL)
@@ -1813,7 +1918,8 @@ ch_device_get_temperature (GUsbDevice *device, gdouble *value,
 			g_set_error (error,
 				     G_USB_DEVICE_ERROR,
 				     G_USB_DEVICE_ERROR_IO,
-				     "Invalid size, got %li", actual_length);
+				     "Invalid size, got %" G_GSIZE_FORMAT,
+				     actual_length);
 			return FALSE;
 		}
 		if (value != NULL)
@@ -1827,6 +1933,128 @@ ch_device_get_temperature (GUsbDevice *device, gdouble *value,
 	return FALSE;
 }
 
+/**
+ * ch_device_get_adc_calibration_pos:
+ * @device: A #GUsbDevice
+ * @value: (out): offset value
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Gets the ADC positive calibration value.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+gboolean
+ch_device_get_adc_calibration_pos (GUsbDevice *device, gdouble *value,
+				   GCancellable *cancellable, GError **error)
+{
+	gboolean ret;
+	gint32 buf[1];
+	gsize actual_length;
+
+	g_return_val_if_fail (G_USB_DEVICE (device), FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	if (ch_device_get_protocol_ver (device) != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "Getting the ADC calibration is not supported");
+		return FALSE;
+	}
+	ret = g_usb_device_control_transfer (device,
+					     G_USB_DEVICE_DIRECTION_DEVICE_TO_HOST,
+					     G_USB_DEVICE_REQUEST_TYPE_CLASS,
+					     G_USB_DEVICE_RECIPIENT_INTERFACE,
+					     CH_CMD_GET_ADC_CALIBRATION_POS,
+					     0x00,		/* wValue */
+					     CH_USB_INTERFACE,	/* idx */
+					     (guint8 *) buf,	/* data */
+					     sizeof(buf),	/* length */
+					     &actual_length,
+					     CH_DEVICE_USB_TIMEOUT,
+					     cancellable,
+					     error);
+	if (!ret)
+		return FALSE;
+
+	/* return result */
+	if (actual_length != sizeof(buf)) {
+		g_set_error (error,
+			     G_USB_DEVICE_ERROR,
+			     G_USB_DEVICE_ERROR_IO,
+			     "Invalid size, got %" G_GSIZE_FORMAT,
+			     actual_length);
+		return FALSE;
+	}
+	if (value != NULL)
+		*value = ch_offset_float_to_double (buf[0]);
+	return TRUE;
+}
+
+/**
+ * ch_device_get_adc_calibration_neg:
+ * @device: A #GUsbDevice
+ * @value: (out): offset value
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Gets the ADC positive calibration value.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+gboolean
+ch_device_get_adc_calibration_neg (GUsbDevice *device, gdouble *value,
+				   GCancellable *cancellable, GError **error)
+{
+	gboolean ret;
+	gint32 buf[1];
+	gsize actual_length;
+
+	g_return_val_if_fail (G_USB_DEVICE (device), FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	if (ch_device_get_protocol_ver (device) != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "Getting the ADC calibration is not supported");
+		return FALSE;
+	}
+	ret = g_usb_device_control_transfer (device,
+					     G_USB_DEVICE_DIRECTION_DEVICE_TO_HOST,
+					     G_USB_DEVICE_REQUEST_TYPE_CLASS,
+					     G_USB_DEVICE_RECIPIENT_INTERFACE,
+					     CH_CMD_GET_ADC_CALIBRATION_NEG,
+					     0x00,		/* wValue */
+					     CH_USB_INTERFACE,	/* idx */
+					     (guint8 *) buf,	/* data */
+					     sizeof(buf),	/* length */
+					     &actual_length,
+					     CH_DEVICE_USB_TIMEOUT,
+					     cancellable,
+					     error);
+	if (!ret)
+		return FALSE;
+
+	/* return result */
+	if (actual_length != sizeof(buf)) {
+		g_set_error (error,
+			     G_USB_DEVICE_ERROR,
+			     G_USB_DEVICE_ERROR_IO,
+			     "Invalid size, got %" G_GSIZE_FORMAT,
+			     actual_length);
+		return FALSE;
+	}
+	if (value != NULL)
+		*value = ch_offset_float_to_double (buf[0]);
+	return TRUE;
+}
+
 /**
  * ch_device_get_error:
  * @device: A #GUsbDevice
@@ -1881,7 +2109,8 @@ ch_device_get_error (GUsbDevice *device, ChError *status, ChCmd *cmd,
 		g_set_error (error,
 			     G_USB_DEVICE_ERROR,
 			     G_USB_DEVICE_ERROR_IO,
-			     "Invalid size, got %li", actual_length);
+			     "Invalid size, got %" G_GSIZE_FORMAT,
+				     actual_length);
 		return FALSE;
 	}
 	if (status != NULL)
@@ -2013,8 +2242,7 @@ ch_device_take_reading_spectral (GUsbDevice *device, ChSpectrumKind value,
 						     G_USB_DEVICE_DIRECTION_DEVICE_TO_HOST,
 						     G_USB_DEVICE_REQUEST_TYPE_CLASS,
 						     G_USB_DEVICE_RECIPIENT_INTERFACE,
-						     0x51,		//FIXME: I have no idea
-						     //CH_CMD_TAKE_READING_SPECTRAL,
+						     CH_CMD_TAKE_READING_SPECTRAL,
 						     value,		/* wValue */
 						     CH_USB_INTERFACE,	/* idx */
 						     NULL,		/* data */
@@ -2104,7 +2332,8 @@ ch_device_take_reading_xyz (GUsbDevice *device, guint16 calibration_idx,
 			g_set_error (error,
 				     G_USB_DEVICE_ERROR,
 				     G_USB_DEVICE_ERROR_IO,
-				     "Invalid size, got %li", actual_length);
+				     "Invalid size, got %" G_GSIZE_FORMAT,
+				     actual_length);
 			return NULL;
 		}
 
@@ -2126,28 +2355,140 @@ ch_device_take_reading_xyz (GUsbDevice *device, guint16 calibration_idx,
 	return NULL;
 }
 
+#define CH_SPECTRUM_STORAGE_SIZE	(CH_CCD_SPECTRAL_RESOLUTION * sizeof(guint16))
+#define CH_PIXELS_PER_TRANSFER		(CH_EP0_TRANSFER_SIZE_V2 / sizeof(guint16))
+
 /**
- * ch_device_get_spectrum:
+ * ch_device_set_spectrum_full:
  * @device: A #GUsbDevice
+ * @kind:  A #ChSpectrumKind
+ * @sp: A #CdSpectrum
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Sets the spectrum from the device. This sends data multiple multiple times
+ * until the spectrum has been populated.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+gboolean
+ch_device_set_spectrum_full (GUsbDevice *device,
+			     ChSpectrumKind kind,
+			     CdSpectrum *sp,
+			     GCancellable *cancellable,
+			     GError **error)
+{
+	gboolean ret;
+	guint16 buf[CH_PIXELS_PER_TRANSFER];
+	gsize actual_length;
+	guint16 i;
+	guint16 j;
+	guint cnt = 0;
+	guint8 protocol_ver = ch_device_get_protocol_ver (device);
+	g_autoptr(CdSpectrum) sp_resampled = NULL;
+
+	g_return_val_if_fail (G_USB_DEVICE (device), FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+
+	if (protocol_ver != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "Setting a spectrum is not supported");
+		return FALSE;
+	}
+
+	/* ensure spectrum has 1024 elements */
+	if (cd_spectrum_get_size (sp) != CH_CCD_SPECTRAL_RESOLUTION) {
+		g_debug ("resampling sample from %u points to 1024",
+			 cd_spectrum_get_size (sp));
+		sp_resampled = cd_spectrum_resample_to_size (sp, 1024);
+	} else {
+		sp_resampled = cd_spectrum_dup (sp);
+	}
+
+	/* i = address in SRAM */
+	for (i = 0; i < CH_SPECTRUM_STORAGE_SIZE; i += CH_EP0_TRANSFER_SIZE_V2) {
+
+		/* create normalised data blob */
+		for (j = 0; j < CH_PIXELS_PER_TRANSFER; j++) {
+			guint16 tmp;
+			gdouble val = cd_spectrum_get_value (sp_resampled, cnt + j);
+			if (val < 0.f || val > 1.f) {
+				g_set_error (error,
+					     CH_DEVICE_ERROR,
+					     CH_ERROR_NOT_IMPLEMENTED,
+					     "expected normalised data for %u, got %f",
+					     j, val);
+				return FALSE;
+			}
+			tmp = val * (gdouble) 0xffff;
+			memcpy (&buf[j], &tmp, sizeof (guint16));
+		}
+		cnt += j;
+
+		/* send to device */
+		ret = g_usb_device_control_transfer (device,
+						     G_USB_DEVICE_DIRECTION_HOST_TO_DEVICE,
+						     G_USB_DEVICE_REQUEST_TYPE_CLASS,
+						     G_USB_DEVICE_RECIPIENT_INTERFACE,
+						     CH_CMD_WRITE_SRAM,
+						     i + (kind * CH_SPECTRUM_STORAGE_SIZE),/* wValue */
+						     CH_USB_INTERFACE,	/* idx */
+						     (guint8 *) buf,	/* data */
+						     sizeof(buf),	/* length */
+						     &actual_length,	/* actual_length */
+						     CH_DEVICE_USB_TIMEOUT,
+						     cancellable,
+						     error);
+		if (!ret)
+			return FALSE;
+		if (actual_length != sizeof(buf)) {
+			g_set_error (error,
+				     G_USB_DEVICE_ERROR,
+				     G_USB_DEVICE_ERROR_IO,
+				     "Failed to get spectrum data, got %" G_GSIZE_FORMAT,
+				     actual_length);
+			return FALSE;
+		}
+	}
+
+	/* check status */
+	if (!ch_device_check_status (device, cancellable, error))
+		return FALSE;
+
+	/* sync to eeprom */
+	if (!ch_device_save_sram (device, cancellable, error))
+		return FALSE;
+
+	/* success */
+	return TRUE;
+}
+
+/**
+ * ch_device_get_spectrum_full:
+ * @device: A #GUsbDevice
+ * @kind:  A #ChSpectrumKind
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
  * Gets the spectrum from the device. This queries the device multiple times
  * until the spectrum has been populated.
  *
- * The spectrum is also set up with the correct start and wavelength
- * calibration coefficients.
- *
  * Returns: a #CdSpectrum, or %NULL for error
  *
- * Since: 1.3.1
+ * Since: 1.3.4
  **/
 CdSpectrum *
-ch_device_get_spectrum (GUsbDevice *device, GCancellable *cancellable, GError **error)
+ch_device_get_spectrum_full (GUsbDevice *device,
+			     ChSpectrumKind kind,
+			     GCancellable *cancellable,
+			     GError **error)
 {
 	gboolean ret;
-	gdouble cal[4];
-	gint32 buf[CH_EP0_TRANSFER_SIZE / sizeof(gint32)];
+	guint16 buf[CH_PIXELS_PER_TRANSFER];
 	gsize actual_length;
 	guint16 i;
 	guint16 j;
@@ -2167,13 +2508,15 @@ ch_device_get_spectrum (GUsbDevice *device, GCancellable *cancellable, GError **
 				     "Getting a spectrum is not supported");
 		return NULL;
 	}
-	for (i = 0; i < 1024 * sizeof(gint32) / CH_EP0_TRANSFER_SIZE; i++) {
+
+	/* i = address in SRAM */
+	for (i = 0; i < CH_SPECTRUM_STORAGE_SIZE; i += CH_EP0_TRANSFER_SIZE_V2) {
 		ret = g_usb_device_control_transfer (device,
 						     G_USB_DEVICE_DIRECTION_DEVICE_TO_HOST,
 						     G_USB_DEVICE_REQUEST_TYPE_CLASS,
 						     G_USB_DEVICE_RECIPIENT_INTERFACE,
 						     CH_CMD_READ_SRAM,
-						     i,			/* wValue */
+						     i + (kind * CH_SPECTRUM_STORAGE_SIZE),/* wValue */
 						     CH_USB_INTERFACE,	/* idx */
 						     (guint8 *) buf,	/* data */
 						     sizeof(buf),	/* length */
@@ -2187,14 +2530,14 @@ ch_device_get_spectrum (GUsbDevice *device, GCancellable *cancellable, GError **
 			g_set_error (error,
 				     G_USB_DEVICE_ERROR,
 				     G_USB_DEVICE_ERROR_IO,
-				     "Failed to get spectrum data, got %li",
+				     "Failed to get spectrum data, got %" G_GSIZE_FORMAT,
 				     actual_length);
 			return NULL;
 		}
 
 		/* add data */
-		for (j = 0; j < CH_EP0_TRANSFER_SIZE / sizeof(gint32); j++) {
-			gdouble tmp = ch_offset_float_to_double (buf[j]);
+		for (j = 0; j < CH_PIXELS_PER_TRANSFER; j++) {
+			gdouble tmp = (gdouble) buf[j] / (gdouble) 0xffff;
 			cd_spectrum_add_value (sp, tmp);
 		}
 	}
@@ -2203,14 +2546,273 @@ ch_device_get_spectrum (GUsbDevice *device, GCancellable *cancellable, GError **
 	if (!ch_device_check_status (device, cancellable, error))
 		return NULL;
 
-	/* add the coefficients */
-	if (!ch_device_get_ccd_calibration (device,
-					    &cal[0], &cal[1], &cal[2], &cal[3],
-					    cancellable, error))
-		return NULL;
-	cd_spectrum_set_start (sp, cal[0]);
-	cd_spectrum_set_wavelength_cal (sp, cal[1], cal[2], cal[3]);
-
 	/* return copy */
 	return cd_spectrum_dup (sp);
 }
+
+/**
+ * ch_device_get_spectrum:
+ * @device: A #GUsbDevice
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Gets the spectrum from the device. This queries the device multiple times
+ * until the spectrum has been populated.
+ *
+ * Returns: a #CdSpectrum, or %NULL for error
+ *
+ * Since: 1.3.1
+ **/
+CdSpectrum *
+ch_device_get_spectrum (GUsbDevice *device, GCancellable *cancellable, GError **error)
+{
+	return ch_device_get_spectrum_full (device, CH_SPECTRUM_KIND_RAW,
+					    cancellable, error);
+}
+
+/**
+ * ch_device_save_sram:
+ * @device: A #GUsbDevice
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Saves the entire SRAM space into the device EEPROM.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+gboolean
+ch_device_save_sram (GUsbDevice *device,
+		     GCancellable *cancellable,
+		     GError **error)
+{
+	gboolean ret;
+
+	if (ch_device_get_protocol_ver (device) != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "saving SRAM not supported");
+		return FALSE;
+	}
+
+	/* save SRAM */
+	ret = g_usb_device_control_transfer (device,
+					     G_USB_DEVICE_DIRECTION_HOST_TO_DEVICE,
+					     G_USB_DEVICE_REQUEST_TYPE_CLASS,
+					     G_USB_DEVICE_RECIPIENT_INTERFACE,
+					     CH_CMD_SAVE_SRAM,
+					     0,			/* wValue */
+					     CH_USB_INTERFACE,	/* idx */
+					     NULL,		/* data */
+					     0,			/* length */
+					     NULL,		/* actual_length */
+					     CH_DEVICE_USB_TIMEOUT,
+					     cancellable,
+					     error);
+	if (!ret)
+		return FALSE;
+
+	/* check status */
+	if (!ch_device_check_status (device, cancellable, error))
+		return FALSE;
+
+	/* success */
+	return TRUE;
+}
+
+/**
+ * ch_device_load_sram:
+ * @device: A #GUsbDevice
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Loads the entire SRAM from the device EEPROM.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+gboolean
+ch_device_load_sram (GUsbDevice *device,
+		     GCancellable *cancellable,
+		     GError **error)
+{
+	gboolean ret;
+
+	if (ch_device_get_protocol_ver (device) != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "saving SRAM not supported");
+		return FALSE;
+	}
+
+	/* save SRAM */
+	ret = g_usb_device_control_transfer (device,
+					     G_USB_DEVICE_DIRECTION_HOST_TO_DEVICE,
+					     G_USB_DEVICE_REQUEST_TYPE_CLASS,
+					     G_USB_DEVICE_RECIPIENT_INTERFACE,
+					     CH_CMD_LOAD_SRAM,
+					     0,			/* wValue */
+					     CH_USB_INTERFACE,	/* idx */
+					     NULL,		/* data */
+					     0,			/* length */
+					     NULL,		/* actual_length */
+					     CH_DEVICE_USB_TIMEOUT,
+					     cancellable,
+					     error);
+	if (!ret)
+		return FALSE;
+
+	/* check status */
+	if (!ch_device_check_status (device, cancellable, error))
+		return FALSE;
+
+	/* success */
+	return TRUE;
+}
+
+/**
+ * ch_device_write_sram:
+ * @device: A #GUsbDevice
+ * @data: A #GBytes
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Loads the entire SRAM from the device EEPROM.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+gboolean
+ch_device_write_sram (GUsbDevice *device,
+		      guint16 addr,
+		      GBytes *data,
+		      GCancellable *cancellable,
+		      GError **error)
+{
+	const guint8 *dataptr;
+	gboolean ret;
+	gsize len;
+
+	if (ch_device_get_protocol_ver (device) != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "writing SRAM not supported");
+		return FALSE;
+	}
+
+	/* write */
+	dataptr = g_bytes_get_data (data, &len);
+	if (len > CH_EP0_TRANSFER_SIZE_V2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "data blob too large");
+		return FALSE;
+	}
+	ret = g_usb_device_control_transfer (device,
+					     G_USB_DEVICE_DIRECTION_HOST_TO_DEVICE,
+					     G_USB_DEVICE_REQUEST_TYPE_CLASS,
+					     G_USB_DEVICE_RECIPIENT_INTERFACE,
+					     CH_CMD_WRITE_SRAM,
+					     addr,		/* wValue */
+					     CH_USB_INTERFACE,	/* idx */
+					     dataptr,		/* data */
+					     len,		/* length */
+					     NULL,		/* actual_length */
+					     CH_DEVICE_USB_TIMEOUT,
+					     cancellable,
+					     error);
+	if (!ret)
+		return FALSE;
+
+	/* check status */
+	if (!ch_device_check_status (device, cancellable, error))
+		return FALSE;
+
+	/* success */
+	return TRUE;
+}
+
+/**
+ * ch_device_read_sram:
+ * @device: A #GUsbDevice
+ * @cancellable: a #GCancellable, or %NULL
+ * @error: a #GError, or %NULL
+ *
+ * Reads a value from the SRAM.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.3.4
+ **/
+GBytes *
+ch_device_read_sram (GUsbDevice *device,
+		     guint16 addr,
+		     guint16 len,
+		     GCancellable *cancellable,
+		     GError **error)
+{
+	gboolean ret;
+	guint8 buf[CH_EP0_TRANSFER_SIZE_V2];
+	gsize actual_length;
+
+	if (ch_device_get_protocol_ver (device) != 2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "reading SRAM not supported");
+		return NULL;
+	}
+
+	/* too big */
+	if (len > CH_EP0_TRANSFER_SIZE_V2) {
+		g_set_error_literal (error,
+				     CH_DEVICE_ERROR,
+				     CH_ERROR_NOT_IMPLEMENTED,
+				     "length too large");
+		return NULL;
+	}
+
+	/* clear the buffer */
+	memset(buf, 0xbe, sizeof(buf));
+
+	/* read SRAM */
+	ret = g_usb_device_control_transfer (device,
+					     G_USB_DEVICE_DIRECTION_DEVICE_TO_HOST,
+					     G_USB_DEVICE_REQUEST_TYPE_CLASS,
+					     G_USB_DEVICE_RECIPIENT_INTERFACE,
+					     CH_CMD_READ_SRAM,
+					     addr,		/* wValue */
+					     CH_USB_INTERFACE,	/* idx */
+					     buf,		/* data */
+					     len,		/* length */
+					     &actual_length,	/* actual_length */
+					     CH_DEVICE_USB_TIMEOUT,
+					     cancellable,
+					     error);
+	if (!ret)
+		return NULL;
+
+	/* check size returned */
+	if (actual_length != len) {
+		g_set_error (error,
+			     G_USB_DEVICE_ERROR,
+			     G_USB_DEVICE_ERROR_IO,
+			     "failed to get SRAM data, got %" G_GSIZE_FORMAT,
+			     actual_length);
+		return NULL;
+	}
+
+	/* check status */
+	if (!ch_device_check_status (device, cancellable, error))
+		return NULL;
+
+	/* success */
+	return g_bytes_new (buf, len);
+}
