@@ -222,7 +222,10 @@ osp_device_query (GUsbDevice *device, OspCmd cmd,
 						 &actual_length,
 						 OSP_USB_TIMEOUT_MS, NULL, error))
 			return FALSE;
-		memcpy (*data_out + offset_wr, buffer_out, OSP_DEVICE_EP_SIZE);
+		if (data_out != NULL) {
+			memcpy (*data_out + offset_wr,
+				buffer_out, OSP_DEVICE_EP_SIZE);
+		}
 		if (g_getenv ("SPARK_PROTOCOL_DEBUG") != NULL)
 			cd_buffer_debug (CD_BUFFER_KIND_RESPONSE, buffer_out, OSP_DEVICE_EP_SIZE);
 		offset_wr += 64;
@@ -325,12 +328,13 @@ osp_device_get_fw_version (GUsbDevice *device, GError **error)
 		g_set_error (error,
 			     OSP_DEVICE_ERROR,
 			     OSP_DEVICE_ERROR_INTERNAL,
-			     "Expected %i bytes, got %li", 2, data_len);
+			     "Expected %i bytes, got %" G_GSIZE_FORMAT,
+			     2, data_len);
 		return NULL;
 	}
 
 	/* format value */
-	return g_strdup_printf ("%i.%i", data[1], data[0]);
+	return g_strdup_printf ("%u.%u", data[1], data[0]);
 }
 
 /**
@@ -361,7 +365,8 @@ osp_device_get_wavelength_cal_for_idx (GUsbDevice *device,
 		g_set_error (error,
 			     OSP_DEVICE_ERROR,
 			     OSP_DEVICE_ERROR_INTERNAL,
-			     "Expected %i bytes, got %li", 4, data_len);
+			     "Expected %i bytes, got %" G_GSIZE_FORMAT,
+			     4, data_len);
 		return FALSE;
 	}
 
@@ -440,7 +445,8 @@ osp_device_get_wavelength_cal (GUsbDevice *device, guint *length, GError **error
 		g_set_error (error,
 			     OSP_DEVICE_ERROR,
 			     OSP_DEVICE_ERROR_INTERNAL,
-			     "Expected 1 bytes, got %li", data_len);
+			     "Expected 1 bytes, got %" G_GSIZE_FORMAT,
+			     data_len);
 		return NULL;
 	}
 
@@ -449,7 +455,7 @@ osp_device_get_wavelength_cal (GUsbDevice *device, guint *length, GError **error
 		g_set_error (error,
 			     OSP_DEVICE_ERROR,
 			     OSP_DEVICE_ERROR_INTERNAL,
-			     "Expected 4 coefs, got %i", data[0]);
+			     "Expected 4 coefs, got %u", data[0]);
 		return NULL;
 	}
 
@@ -501,7 +507,8 @@ osp_device_get_nonlinearity_cal_for_idx (GUsbDevice *device,
 		g_set_error (error,
 			     OSP_DEVICE_ERROR,
 			     OSP_DEVICE_ERROR_INTERNAL,
-			     "Expected %i bytes, got %li", 4, data_len);
+			     "Expected %i bytes, got %" G_GSIZE_FORMAT,
+			     4, data_len);
 		return FALSE;
 	}
 
@@ -548,7 +555,8 @@ osp_device_get_nonlinearity_cal (GUsbDevice *device, guint *length, GError **err
 		g_set_error (error,
 			     OSP_DEVICE_ERROR,
 			     OSP_DEVICE_ERROR_INTERNAL,
-			     "Expected 1 bytes, got %li", data_len);
+			     "Expected 1 bytes, got %" G_GSIZE_FORMAT,
+			     data_len);
 		return NULL;
 	}
 
@@ -614,7 +622,8 @@ osp_device_get_irradiance_cal (GUsbDevice *device, guint *length, GError **error
 		g_set_error (error,
 			     OSP_DEVICE_ERROR,
 			     OSP_DEVICE_ERROR_INTERNAL,
-			     "Expected %i bytes, got %li", 4096 * 4, data_len);
+			     "Expected %i bytes, got %" G_GSIZE_FORMAT,
+			     4096 * 4, data_len);
 		return NULL;
 	}
 
@@ -664,7 +673,8 @@ osp_device_take_spectrum_internal (GUsbDevice *device,
 		g_set_error (error,
 			     OSP_DEVICE_ERROR,
 			     OSP_DEVICE_ERROR_INTERNAL,
-			     "Expected %i bytes, got %li", 2048, data_len);
+			     "Expected %i bytes, got %" G_GSIZE_FORMAT,
+			     2048, data_len);
 		return NULL;
 	}
 
@@ -798,7 +808,8 @@ osp_device_take_spectrum (GUsbDevice *device, GError **error)
 		max = cd_spectrum_get_value_max (sp_probe);
 		if (max < 0.001f) {
 			sample_duration *= 100.f;
-			g_debug ("sensor read no data, setting duration to %luus",
+			g_debug ("sensor read no data, setting duration "
+				 "to %" G_GUINT64_FORMAT ,
 				 sample_duration);
 			continue;
 		}
@@ -806,7 +817,8 @@ osp_device_take_spectrum (GUsbDevice *device, GError **error)
 		/* sensor is saturated, take action */
 		if (max > 0.99f) {
 			sample_duration /= 100.f;
-			g_debug ("sensor saturated, setting duration to %luus",
+			g_debug ("sensor saturated, setting duration "
+				 "to %" G_GUINT64_FORMAT,
 				 sample_duration);
 			continue;
 		}
@@ -826,14 +838,14 @@ osp_device_take_spectrum (GUsbDevice *device, GError **error)
 		/* aim for FSD / 2 */
 		scale = (gdouble) 0.5 / max;
 		sample_duration *= scale;
-		g_debug ("for max of %f, using scale=%f for duration %luus",
+		g_debug ("for max of %f, using scale=%f for duration %" G_GUINT64_FORMAT,
 			 max, scale, sample_duration);
 
 		/* limit this to something sane */
 		if (sample_duration / G_USEC_PER_SEC > sample_duration_max_secs) {
-			g_debug ("limiting duration from %lus to %is",
-				 sample_duration / G_USEC_PER_SEC,
-				 sample_duration_max_secs);
+			g_debug ("limiting duration from %us to %us",
+				 (guint) (sample_duration / G_USEC_PER_SEC),
+				 (guint) (sample_duration_max_secs));
 			sample_duration = sample_duration_max_secs * G_USEC_PER_SEC;
 			relax_requirements = TRUE;
 		}
